
--[[

A Combat Analysis Tab Menu specifies what should appear
in the context menu when a Combat Analysis Tab is right
clicked.

Standard options include a "Close Tab" item and an
"Add Tab" option, where the tabs that are available
to add are determined by the tab's tabSet field.

]]--

_G.CombatAnalysisTabMenu = class(Turbine.UI.ContextMenu);

function CombatAnalysisTabMenu:Constructor()
	Turbine.UI.ContextMenu.Constructor(self);
	
	self.items = self:GetItems();
	
	self.title = Turbine.UI.MenuItem("",false);
	
	self.addTab = Turbine.UI.MenuItem(L.RestoreTab);
	self.addTabItems = self.addTab:GetItems();
	self.closeTab = Turbine.UI.MenuItem(L.CloseTab);
	
	self.autoHideTabs = Turbine.UI.MenuItem(L.AutoHideTabs,true,false);
	self.showBackground = Turbine.UI.MenuItem(L.ShowBackground,true,true);
	self.showMiniTitleBar = Turbine.UI.MenuItem(L.ShowMiniTitleBar,true,true);
	
	self.items:Add(self.title);
	self.items:Add(self.addTab);
	self.items:Add(self.closeTab);
	self.items:Add(self.autoHideTabs);
	self.items:Add(self.showBackground);
	self.items:Add(self.showMiniTitleBar);
end

function CombatAnalysisTabMenu:PopulateMenu(tab)
	self.title:SetText(tab.text);
	
	self.addTabItems:Clear();
	
	for _,restorableTab in pairs(tab.tabSet) do
		if (restorableTab.window == nil) then
			local add = Turbine.UI.MenuItem(restorableTab.text);
			add.Click = function(sender,args)
				tab.window:AddTab(restorableTab,false);
				
				local noTabsRemaining = 0;
				for _,t in pairs(tab.tabSet) do
					noTabsRemaining = noTabsRemaining + (t.window == nil and 0 or 1);
				end
				if (noTabsRemaining == 2) then
					self.closeTab:SetEnabled(true);
				end
				
				restorableTab:SaveState();
			end
			self.addTabItems:Add(add);
		end
	end
	
	if (self.addTabItems:GetCount() > 0) then
		self.addTab:SetEnabled(true);
	else
		self.addTab:SetEnabled(false);
	end
	
	local noTabsRemaining = 0;
	for _,t in ipairs(tab.tabSet) do
		noTabsRemaining = noTabsRemaining + (t.window == nil and 0 or 1);
	end
	if (noTabsRemaining == 1) then
		self.closeTab:SetEnabled(false);
	else
		self.closeTab:SetEnabled(true);
	end
	self.closeTab.Click = function(sender,args)
		tab.window:RemoveTab(tab);
		tab:SaveState();
	end
	
	self.autoHideTabs:SetChecked(tab.window.autoHideTabs);
	self.autoHideTabs.Click = function(sender,args)
		self.autoHideTabs:SetChecked(not self.autoHideTabs:IsChecked());
		tab.window:SetAutoHideTabs(self.autoHideTabs:IsChecked());
		tab.window:SaveState();
	end
	
	self.showBackground:SetChecked(tab.window.showBackground);
	self.showBackground.Click = function(sender,args)
		self.showBackground:SetChecked(not self.showBackground:IsChecked());
		tab.window:SetShowBackground(self.showBackground:IsChecked());
		tab.window:SaveState();
	end
	
	self.showMiniTitleBar:SetChecked(tab.window.titleBarWidth > 0);
	self.showMiniTitleBar.Click = function(sender,args)
		self.showMiniTitleBar:SetChecked(not self.showMiniTitleBar:IsChecked());
		tab.window:SetTitleBarWidth(self.showMiniTitleBar:IsChecked() and CombatAnalysisWindow.defaultTitleBarWidth or 0);
		tab.window:SaveState();
	end
end
