
--[[

A Bombat Analysis Window is a simple window with a cut off
title bar in the top right, and can be moved and resized.

It also includes a chat box style resize icon in the lower
right corner.

All content should be added to the "self.content" pane,
whose Layout() method, which should be overridden,
will determine how internal elements are displayed. There
is also a "self.titleContent" pane for adding content
to the title bar.

The "self.content" pane is located directly inside of the
window border. The "self.titleContent" pane is located
directly inside the title border, and excludes the cut
off area.

]]--

_G.CombatAnalysisTitleBar = class(Turbine.UI.Control);

function CombatAnalysisTitleBar:Constructor(window,backgroundColor,closable)
	Turbine.UI.Control.Constructor(self);
	
	self.window = window;
	self.gapSize = Misc.Round((CombatAnalysisWindow.titleBarHeight-16)/2);
	
	self:SetParent(self.window);
	self:SetBackColor(backgroundColor);
	self:SetMouseVisible(true);
	
	self.MouseDown = function(sender,args) self.window:MouseDown(args) end
	self.MouseUp = function(sender,args) self.window:MouseUp(args) end
	self.MouseMove = function(sender,args) self.window:MouseMove(args) end
	
	-- close button
	self.close = Turbine.UI.Control();
	self.close:SetParent(self);
	self.close:SetTop(self.gapSize);
	self.close:SetSize(16,16);
	self.close:SetZOrder(4);
	self.close:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	self.close:SetBackground("CombatAnalysis/Resources/titlebar_X_2"..(closable and "" or "_sepia")..".tga");
	self.close.enabled = closable;
	self.close.pressed = false;
	self.close.MouseEnter = function(sender, args)
		if (self.close.enabled) then
			self.close:SetBackground("CombatAnalysis/Resources/titlebar_X_2_"..(self.close.pressed and "pressed" or "mouseover")..".tga");
		end
	end
	self.close.MouseLeave = function(sender, args)
		if (self.close.enabled) then
			self.close:SetBackground("CombatAnalysis/Resources/titlebar_X_2"..(self.close.pressed and "_mouseover" or "")..".tga");
		end
	end
	self.close.MouseDown = function(sender, args)
		WindowManager.MouseWasPressed(self.window);
		if (self.close.enabled) then
			self.close.pressed = true;
			self.close:SetBackground("CombatAnalysis/Resources/titlebar_X_2_pressed.tga");
		end
	end
	self.close.MouseUp = function(sender, args)
		if (self.close.enabled) then
			self.close.pressed = false;
			self.close:SetBackground("CombatAnalysis/Resources/titlebar_X_2.tga");
		end
	end
	self.close.MouseClick = function(sender, args)
		if (self.close.enabled) then
			self.window:Close();
		end
	end
	
	-- minimize button
	self.minimize = Turbine.UI.Control();
	self.minimize:SetParent(self);
	self.minimize:SetTop(self.gapSize);
	self.minimize:SetSize(16,16);
	self.minimize:SetZOrder(4);
	self.minimize:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	self.minimize:SetBackground("CombatAnalysis/Resources/titlebar_min.tga");
	self.minimize.pressed = false;
	self.minimize.MouseEnter = function(sender, args)
		if (self.window.minimized) then
			self.minimize:SetBackground("CombatAnalysis/Resources/titlebar_max_"..(self.minimize.pressed and "pressed" or "mouseover")..".tga");
		else
			self.minimize:SetBackground("CombatAnalysis/Resources/titlebar_min_"..(self.minimize.pressed and "pressed" or "mouseover")..".tga");
		end
	end
	self.minimize.MouseLeave = function(sender, args)
		if (self.window.minimized) then
			self.minimize:SetBackground("CombatAnalysis/Resources/titlebar_max"..(self.minimize.pressed and "_mouseover" or "")..".tga");
		else
			self.minimize:SetBackground("CombatAnalysis/Resources/titlebar_min"..(self.minimize.pressed and "_mouseover" or "")..".tga");
		end
	end
	self.minimize.MouseDown = function(sender, args)
		WindowManager.MouseWasPressed(self.window);
		self.minimize.pressed = true;
		self.minimize:SetBackground("CombatAnalysis/Resources/titlebar_"..(self.window.minimized and "max" or "min").."_pressed.tga");
	end
	self.minimize.MouseUp = function(sender, args)
		self.minimize.pressed = false;
		self.minimize:SetBackground("CombatAnalysis/Resources/titlebar_"..(self.window.minimized and "max" or "min")..".tga");
	end
	self.minimize.MouseClick = function(sender, args)
		self.window:Minimize();
		self.minimize:SetBackground("CombatAnalysis/Resources/titlebar_"..(self.window.minimized and "max" or "min").."_mouseover.tga");
	end
	self.minimize.MouseDoubleClick = function(sender, args)
		self.minimize:MouseClick(args);
	end
	
	-- load button
	self.load = Turbine.UI.Control();
	self.load:SetParent(self);
	self.load:SetTop(self.gapSize);
	self.load:SetSize(16,16);
	self.load:SetZOrder(4);
	self.load:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	
	self.loadImage = Turbine.UI.Control();
	self.loadImage:SetParent(self.load);
	self.loadImage:SetPosition(2,2);
	self.loadImage:SetSize(12,12);	
	self.loadImage:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	self.loadImage:SetBackground("CombatAnalysis/Resources/load.tga");
	self.loadImage:SetMouseVisible(false);
	
	self.load.pressed = false;
	
	self.load.MouseEnter = function(sender, args)
		if (self.load.pressed) then
			self.loadImage:SetPosition(3,3);
		end
	end
	self.load.MouseLeave = function(sender, args)
		if (self.load.pressed) then
			self.loadImage:SetPosition(2,2);
		end
	end
	self.load.MouseDown = function(sender, args)
		WindowManager.MouseWasPressed(self.window);
		self.load.pressed = true;
		self.loadImage:SetPosition(3,3);
	end
	self.load.MouseUp = function(sender, args)
		self.load.pressed = false;
		self.loadImage:SetPosition(2,2);
	end
	self.load.MouseClick = function(sender, args)
		fileSelectDialog:Show(false);
	end
	
	-- save button
	self.save = Turbine.UI.Control();
	self.save:SetParent(self);
	self.save:SetTop(self.gapSize);
	self.save:SetSize(16,16);
	self.save:SetZOrder(4);
	
	self.saveImage = Turbine.UI.Control();
	self.saveImage:SetParent(self.save);
	self.saveImage:SetPosition(2,2);
	self.saveImage:SetSize(12,12);
	self.saveImage:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	self.saveImage:SetBackground("CombatAnalysis/Resources/save.tga");
	self.saveImage:SetMouseVisible(false);
	
	self.save.pressed = false;
	
	self.save.MouseEnter = function(sender, args)
		if (self.save.pressed) then
			self.saveImage:SetPosition(3,3);
		end
	end
	self.save.MouseLeave = function(sender, args)
		if (self.save.pressed) then
			self.saveImage:SetPosition(2,2);
		end
	end
	self.save.MouseDown = function(sender, args)
		WindowManager.MouseWasPressed(self.window);
		self.save.pressed = true;
		self.saveImage:SetPosition(3,3);
	end
	self.save.MouseUp = function(sender, args)
		self.save.pressed = false;
		self.saveImage:SetPosition(2,2);
	end
	self.save.MouseClick = function(sender, args)
		fileSelectDialog:Show(true);
	end
	
	self:Layout();
end

function CombatAnalysisTitleBar:Layout()
	local w,h = self:GetSize();
	
	self.close:SetLeft(w-16-self.gapSize);
	self.minimize:SetLeft(w-2*(16+self.gapSize));
	self.load:SetLeft(w-3*(16+self.gapSize)-self.gapSize);
	self.save:SetLeft(w-4*(16+self.gapSize));
end

function CombatAnalysisTitleBar:EnableClose(enable)
	self.close.enabled = enable;
	
	if (self.close.enabled) then
		self.close:SetBackground("CombatAnalysis/Resources/titlebar_X_2.tga");
	else
		self.close:SetBackground("CombatAnalysis/Resources/titlebar_X_2_sepia.tga");
	end
end
